@@ -32,6 +32,8 @@ class MagicCallLogger(APIRoute):
                     context = request.scope["aws.context"]
                     if hasattr(context, "serverless_sdk"):
                         print("Saving sls context for error!")
+                        context.serverless_sdk.set_endpoint(request.url.path)
+                        print("set req url")
                         context.serverless_sdk.capture_exception(e)
                 print("Error in call route", e.__dict__)
                 error = e
